@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 from datetime import datetime, timedelta, timezone
 from enum import Enum
+from typing import Any
 
 import jwt
 
@@ -15,7 +16,7 @@ class Action(str, Enum):
 @dataclass
 class PastaportoAction:
     action: Action
-    payload: dict[str, str]
+    payload: dict[str, Any]
 
     def sign(self, secret: str) -> str:
         now = datetime.now(timezone.utc)
@@ -38,11 +39,9 @@ def create_pastaporto_action(
     return PastaportoAction(action=action, payload=payload)
 
 
-def create_user_auth_pastaporto_action(user_id: int, jwt_auth_id: int) -> PastaportoAction:
+def create_user_auth_pastaporto_action(
+    user_id: int, jwt_auth_id: int
+) -> PastaportoAction:
     return create_pastaporto_action(
-        Action.AUTH,
-        {
-            "id": user_id,
-            'jwtAuthId': jwt_auth_id
-        }
+        Action.AUTH, {"id": user_id, "jwtAuthId": jwt_auth_id}
     )
